@@ -127,9 +127,7 @@ class GraphGenerator(_BaseGraphSingleGenerator):
     ...
     "node_atom_idx",
     "node_ele_idx"
-    "ele_atom_idx"
-     ]
-
+    "ele_atom_idx"]
     """
 
     def __init__(
@@ -240,23 +238,23 @@ class MGEDataLoader:
     Notes:
         we replace the last 2 features in primary features to index list feature and add 1 features.
 
-        len_node_atom -> node_atom_idx_idx
+        len_node_atom -> node_atom_idx
 
-        len_node_ele -> node_ele_idx_idx
+        len_node_ele -> node_ele_idx
 
-        ele_atom_idx -> node_ele_idx_idx
+        ele_atom_idx -> node_ele_idx
 
     Thus the number of final features are add 1 to input dataset.
 
     CrystalGraphDisordered,CrystalGraph,SingleMoleculeGraph in crystal, return 7 features.
     Return:
-        ["atom_feature", "nbr_feature", "state_feature", 'atom_nbr_idx',
-        "node_atom_idx", "node_ele_idx","ele_atom_idx"]
+    ["atom_feature", "nbr_feature", "state_feature", 'atom_nbr_idx',
+    "node_atom_idx", "node_ele_idx","ele_atom_idx"]
 
     other Graph self-defined, Return:
-        ["atom_feature", "nbr_feature", "state_feature", 'atom_nbr_idx',
-        ...
-        "node_atom_idx", "node_ele_idx","ele_atom_idx"]
+    ["atom_feature", "nbr_feature", "state_feature", 'atom_nbr_idx',
+    ...
+    "node_atom_idx", "node_ele_idx","ele_atom_idx"]
 
     """
 
